OpalineStyle

Struct OpalineStyle 

#[non_exhaustive]
pub struct OpalineStyle { pub fg: Option<OpalineColor>, pub bg: Option<OpalineColor>, pub bold: bool, pub dim: bool, pub italic: bool, pub underline: bool, pub slow_blink: bool, pub rapid_blink: bool, pub reversed: bool, pub hidden: bool, pub crossed_out: bool, }
A composed style with optional foreground/background colors and text modifiers.

Styles are the output of the resolution pipeline — they reference resolved colors (not token names) and can be converted to ratatui::style::Style via the adapter.

All 9 ratatui modifiers are supported: bold, dim, italic, underline, slow_blink, rapid_blink, reversed, hidden, and crossed_out.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
fg: Option<OpalineColor>bg: Option<OpalineColor>bold: booldim: boolitalic: boolunderline: boolslow_blink: boolrapid_blink: boolreversed: boolhidden: boolcrossed_out: bool

Implementations

Source

impl OpalineStyle

pub const fn new() -> Self

Create an empty style with no colors or modifiers.

pub const fn fg(color: OpalineColor) -> Self

Create a style with only a foreground color.

pub const fn bg(color: OpalineColor) -> Self

Create a style with only a background color.

pub const fn with_fg(self, color: OpalineColor) -> Self

Set the foreground color.

pub const fn with_bg(self, color: OpalineColor) -> Self

Set the background color.

pub const fn bold(self) -> Self

Enable bold.

pub const fn dim(self) -> Self

Enable dim.

pub const fn italic(self) -> Self

Enable italic.

pub const fn underline(self) -> Self

Enable underline.

Enable slow blink.

Enable rapid blink.

pub const fn reversed(self) -> Self

Enable reversed (inverted fg/bg).

pub const fn hidden(self) -> Self

Enable hidden.

pub const fn crossed_out(self) -> Self

Enable crossed out (strikethrough).

pub fn merge(&self, other: &Self) -> Self

Merge another style on top of this one.

The other style takes precedence for colors where set. Boolean modifiers are OR’d together.