Module theme

Module theme 

Structs

Theme
A fully resolved theme ready for use.
ThemeBuilder
Programmatic theme construction without TOML.

Functions

current
Get a snapshot of the currently active global theme.
load_theme
Load a theme from a file and set it as the active global theme.
load_theme_by_name
Load a theme by name and set it as the active global theme.
load_theme_by_name_for_app
Load a theme by name, searching app-specific discovery paths too.
load_theme_by_name_for_app_with
Like load_theme_by_name_for_app but with an app-level derivation callback.
load_theme_by_name_with
Load a theme by name, run an app-level derivation callback, then set as the active global theme.
set_theme
Replace the active global theme.