pub fn load_theme(path: &Path) -> Result<(), OpalineError>Expand description
Load a theme from a file and set it as the active global theme.
pub fn load_theme(path: &Path) -> Result<(), OpalineError>Load a theme from a file and set it as the active global theme.