Structs
- Theme
- A fully resolved theme ready for use.
- Theme
Builder - Programmatic theme construction without TOML.
Functions
- current
- Get a snapshot of the currently active global theme.
- load_
theme - Load a theme from a file and set it as the active global theme.
- load_
theme_ by_ name - Load a theme by name and set it as the active global theme.
- load_
theme_ by_ name_ for_ app - Load a theme by name, searching app-specific discovery paths too.
- load_
theme_ by_ name_ for_ app_ with - Like
load_theme_by_name_for_appbut with an app-level derivation callback. - load_
theme_ by_ name_ with - Load a theme by name, run an app-level derivation callback, then set as the active global theme.
- set_
theme - Replace the active global theme.